package betterquesting.api2.client.gui.panels.lists;

import betterquesting.api.api.ApiReference;
import betterquesting.api.api.QuestingAPI;
import betterquesting.api.enums.EnumQuestState;
import betterquesting.api.properties.NativeProps;
import betterquesting.api.questing.IQuest;
import betterquesting.api.questing.IQuestDatabase;
import betterquesting.api.questing.IQuestLine;
import betterquesting.api.questing.IQuestLineEntry;
import betterquesting.api2.cache.QuestCache;
import betterquesting.api2.client.gui.controls.PanelButtonQuest;
import betterquesting.api2.client.gui.misc.GuiRectangle;
import betterquesting.api2.client.gui.misc.IGuiRect;
import betterquesting.api2.client.gui.panels.content.PanelGeneric;
import betterquesting.api2.client.gui.panels.content.PanelLine;
import betterquesting.api2.client.gui.resources.colors.IGuiColor;
import betterquesting.api2.client.gui.resources.lines.IGuiLine;
import betterquesting.api2.client.gui.resources.textures.SimpleTexture;
import betterquesting.api2.client.gui.themes.presets.PresetColor;
import betterquesting.api2.client.gui.themes.presets.PresetLine;
import betterquesting.api2.storage.DBEntry;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;
import net.minecraft.client.Minecraft;
import net.minecraft.client.entity.EntityClientPlayerMP;
import net.minecraft.util.ResourceLocation;
import net.minecraft.util.StringUtils;

/* loaded from: betterquesting_api2_client_gui_panels_lists.jar:betterquesting/api2/client/gui/panels/lists/CanvasQuestLine.class */
public class CanvasQuestLine extends CanvasScrolling {
    private final List<PanelButtonQuest> btnList;
    private final int buttonId;
    private IQuestLine lastQL;

    public CanvasQuestLine(IGuiRect rect, int buttonId) {
        super(rect);
        this.btnList = new ArrayList();
        setupAdvanceScroll(true, true, 24);
        enableBlocking(false);
        this.buttonId = buttonId;
    }

    public Collection<PanelButtonQuest> getQuestButtons() {
        return Collections.unmodifiableCollection(this.btnList);
    }

    public PanelButtonQuest getButtonAt(int mx, int my) {
        float zs = ((Float) this.zoomScale.readValue()).floatValue();
        int tx = getTransform().getX();
        int ty = getTransform().getY();
        int smx = ((int) ((mx - tx) / zs)) + this.lsx;
        int smy = ((int) ((my - ty) / zs)) + this.lsy;
        for (PanelButtonQuest btn : this.btnList) {
            if (btn.rect.contains(smx, smy)) {
                return btn;
            }
        }
        return null;
    }

    public IQuestLine getQuestLine() {
        return this.lastQL;
    }

    public void refreshQuestLine() {
        setQuestLine(this.lastQL);
    }

    /* JADX WARN: Failed to find 'out' block for switch in B:26:0x01ea. Please report as an issue. */
    public void setQuestLine(IQuestLine line) {
        resetCanvas();
        this.btnList.clear();
        this.lastQL = line;
        if (line == null) {
            return;
        }
        EntityClientPlayerMP entityClientPlayerMP = Minecraft.func_71410_x().field_71439_g;
        UUID pid = QuestingAPI.getQuestingUUID(entityClientPlayerMP);
        String bgString = (String) line.getProperty(NativeProps.BG_IMAGE);
        if (!StringUtils.func_151246_b(bgString)) {
            int bgSize = ((Integer) line.getProperty(NativeProps.BG_SIZE)).intValue();
            addPanel(new PanelGeneric(new GuiRectangle(0, 0, bgSize, bgSize, 1), new SimpleTexture(new ResourceLocation(bgString), new GuiRectangle(0, 0, 256, 256))));
        }
        HashMap<Integer, PanelButtonQuest> questBtns = new HashMap<>();
        for (DBEntry<IQuestLineEntry> qle : line.getEntries()) {
            IQuest quest = (IQuest) ((IQuestDatabase) QuestingAPI.getAPI(ApiReference.QUEST_DB)).getValue(qle.getID());
            if (QuestCache.isQuestShown(quest, pid, entityClientPlayerMP)) {
                GuiRectangle rect = new GuiRectangle(((IQuestLineEntry) qle.getValue()).getPosX(), ((IQuestLineEntry) qle.getValue()).getPosY(), ((IQuestLineEntry) qle.getValue()).getSizeX(), ((IQuestLineEntry) qle.getValue()).getSizeY());
                PanelButtonQuest paBtn = new PanelButtonQuest(rect, this.buttonId, "", new DBEntry(qle.getID(), quest));
                addPanel(paBtn);
                this.btnList.add(paBtn);
                questBtns.put(Integer.valueOf(qle.getID()), paBtn);
            }
        }
        for (Map.Entry<Integer, PanelButtonQuest> entry : questBtns.entrySet()) {
            DBEntry<IQuest> quest2 = (DBEntry) entry.getValue().getStoredValue();
            List<DBEntry<IQuest>> reqList = ((IQuestDatabase) QuestingAPI.getAPI(ApiReference.QUEST_DB)).bulkLookup(((IQuest) quest2.getValue()).getRequirements());
            if (reqList.size() > 0) {
                boolean main = ((Boolean) ((IQuest) quest2.getValue()).getProperty(NativeProps.MAIN)).booleanValue();
                EnumQuestState qState = ((IQuest) quest2.getValue()).getState(pid);
                IGuiLine lineRender = null;
                IGuiColor txLineCol = null;
                switch (AnonymousClass1.$SwitchMap$betterquesting$api$enums$EnumQuestState[qState.ordinal()]) {
                    case 1:
                        lineRender = PresetLine.QUEST_LOCKED.getLine();
                        txLineCol = PresetColor.QUEST_LINE_LOCKED.getColor();
                        break;
                    case 2:
                        lineRender = PresetLine.QUEST_UNLOCKED.getLine();
                        txLineCol = PresetColor.QUEST_LINE_UNLOCKED.getColor();
                        break;
                    case 3:
                        lineRender = PresetLine.QUEST_PENDING.getLine();
                        txLineCol = PresetColor.QUEST_LINE_PENDING.getColor();
                        break;
                    case 4:
                        lineRender = PresetLine.QUEST_COMPLETE.getLine();
                        txLineCol = PresetColor.QUEST_LINE_COMPLETE.getColor();
                        break;
                }
                for (DBEntry<IQuest> req : reqList) {
                    PanelButtonQuest parBtn = questBtns.get(Integer.valueOf(req.getID()));
                    if (parBtn != null) {
                        PanelLine prLine = new PanelLine(parBtn.getTransform(), entry.getValue().getTransform(), lineRender, main ? 8 : 4, txLineCol, 1);
                        addPanel(prLine);
                    }
                }
            }
        }
        fitToWindow();
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* renamed from: betterquesting.api2.client.gui.panels.lists.CanvasQuestLine$1, reason: invalid class name */
    /* loaded from: betterquesting_api2_client_gui_panels_lists.jar:betterquesting/api2/client/gui/panels/lists/CanvasQuestLine$1.class */
    public static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$betterquesting$api$enums$EnumQuestState = new int[EnumQuestState.values().length];

        static {
            try {
                $SwitchMap$betterquesting$api$enums$EnumQuestState[EnumQuestState.LOCKED.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$betterquesting$api$enums$EnumQuestState[EnumQuestState.UNLOCKED.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$betterquesting$api$enums$EnumQuestState[EnumQuestState.UNCLAIMED.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$betterquesting$api$enums$EnumQuestState[EnumQuestState.COMPLETED.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
        }
    }

    public void fitToWindow() {
        boolean flag = false;
        int minX = 0;
        int minY = 0;
        int maxX = 0;
        int maxY = 0;
        for (PanelButtonQuest btn : this.btnList) {
            GuiRectangle rect = btn.rect;
            if (!flag) {
                minX = rect.getX();
                minY = rect.getY();
                maxX = minX + rect.getWidth();
                maxY = minY + rect.getHeight();
                flag = true;
            } else {
                minX = Math.min(minX, rect.getX());
                minY = Math.min(minY, rect.getY());
                maxX = Math.max(maxX, rect.getX() + rect.getWidth());
                maxY = Math.max(maxY, rect.getY() + rect.getHeight());
            }
        }
        int minX2 = minX - this.margin;
        int minY2 = minY - this.margin;
        setZoom(Math.min(getTransform().getWidth() / ((maxX + this.margin) - minX2), getTransform().getHeight() / ((maxY + this.margin) - minY2)));
        refreshScrollBounds();
        IGuiRect bounds = getScrollBounds();
        setScrollX(bounds.getX() + (bounds.getWidth() / 2));
        setScrollY(bounds.getY() + (bounds.getHeight() / 2));
        updatePanelScroll();
    }
}
